pub struct CreateCapacityReservationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateCapacityReservation.
Creates a capacity reservation with the specified name and number of requested data processing units.
Implementations
Sourceimpl CreateCapacityReservationFluentBuilder
impl CreateCapacityReservationFluentBuilder
Sourcepub fn as_input(&self) -> &CreateCapacityReservationInputBuilder
pub fn as_input(&self) -> &CreateCapacityReservationInputBuilder
Access the CreateCapacityReservation as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateCapacityReservationOutput, SdkError<CreateCapacityReservationError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateCapacityReservationOutput, SdkError<CreateCapacityReservationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateCapacityReservationOutput, CreateCapacityReservationError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateCapacityReservationOutput, CreateCapacityReservationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn target_dpus(self, input: i32) -> Self
pub fn target_dpus(self, input: i32) -> Self
The number of requested data processing units.
Sourcepub fn set_target_dpus(self, input: Option<i32>) -> Self
pub fn set_target_dpus(self, input: Option<i32>) -> Self
The number of requested data processing units.
Sourcepub fn get_target_dpus(&self) -> &Option<i32>
pub fn get_target_dpus(&self) -> &Option<i32>
The number of requested data processing units.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the capacity reservation to create.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the capacity reservation to create.
Appends an item to Tags.
To override the contents of this collection use set_tags.
The tags for the capacity reservation.
The tags for the capacity reservation.
The tags for the capacity reservation.