#[non_exhaustive]pub struct CreateCapacityReservationInputBuilder { /* private fields */ }Expand description
A builder for CreateCapacityReservationInput.
Implementations
Sourceimpl CreateCapacityReservationInputBuilder
impl CreateCapacityReservationInputBuilder
Sourcepub fn target_dpus(self, input: i32) -> Self
pub fn target_dpus(self, input: i32) -> Self
The number of requested data processing units.
This field is required.Sourcepub fn set_target_dpus(self, input: Option<i32>) -> Self
pub fn set_target_dpus(self, input: Option<i32>) -> Self
The number of requested data processing units.
Sourcepub fn get_target_dpus(&self) -> &Option<i32>
pub fn get_target_dpus(&self) -> &Option<i32>
The number of requested data processing units.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the capacity reservation to create.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the capacity reservation to create.
Appends an item to tags.
To override the contents of this collection use set_tags.
The tags for the capacity reservation.
The tags for the capacity reservation.
The tags for the capacity reservation.
Sourcepub fn build(self) -> Result<CreateCapacityReservationInput, BuildError>
pub fn build(self) -> Result<CreateCapacityReservationInput, BuildError>
Consumes the builder and constructs a CreateCapacityReservationInput.
Sourceimpl CreateCapacityReservationInputBuilder
impl CreateCapacityReservationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateCapacityReservationOutput, SdkError<CreateCapacityReservationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateCapacityReservationOutput, SdkError<CreateCapacityReservationError, HttpResponse>>
Sends a request with this input using the given client.